.. nodoctest

About morphisms between free groups: connecting with the ``train_track`` package
================================================================================

.. automodule:: stallings_graphs.about_TC_morphisms
   :members:
   :undoc-members:
   :show-inheritance:
   

